==> cdk8s-plus-20-1.0.0-beta.6-sources.jar: org/cdk8s/plus20/EnvValue.java <==
package org.cdk8s.plus20;

/**
 * Utility class for creating reading env values from various sources.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.34.0 (build 9b72778)", date = "2021-09-24T02:12:24.246Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = org.cdk8s.plus20.$Module.class, fqn = "cdk8s-plus-20.EnvValue")
public class EnvValue extends software.amazon.jsii.JsiiObject {

    protected EnvValue(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected EnvValue(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Create a value by reading a specific key inside a config map.
     * <p>
     * @param configMap - The config map. This parameter is required.
     * @param key - The key to extract the value from. This parameter is required.
     * @param options - Additional options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.EnvValue fromConfigMap(final @org.jetbrains.annotations.NotNull org.cdk8s.plus20.IConfigMap configMap, final @org.jetbrains.annotations.NotNull java.lang.String key, final @org.jetbrains.annotations.Nullable org.cdk8s.plus20.EnvValueFromConfigMapOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.EnvValue.class, "fromConfigMap", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.EnvValue.class), new Object[] { java.util.Objects.requireNonNull(configMap, "configMap is required"), java.util.Objects.requireNonNull(key, "key is required"), options });
    }

    /**
     * Create a value by reading a specific key inside a config map.
     * <p>
     * @param configMap - The config map. This parameter is required.
     * @param key - The key to extract the value from. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.EnvValue fromConfigMap(final @org.jetbrains.annotations.NotNull org.cdk8s.plus20.IConfigMap configMap, final @org.jetbrains.annotations.NotNull java.lang.String key) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.EnvValue.class, "fromConfigMap", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.EnvValue.class), new Object[] { java.util.Objects.requireNonNull(configMap, "configMap is required"), java.util.Objects.requireNonNull(key, "key is required") });
    }

    /**
     * Create a value from a key in the current process environment.
     * <p>
     * @param key - The key to read. This parameter is required.
     * @param options - Additional options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.EnvValue fromProcess(final @org.jetbrains.annotations.NotNull java.lang.String key, final @org.jetbrains.annotations.Nullable org.cdk8s.plus20.EnvValueFromProcessOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.EnvValue.class, "fromProcess", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.EnvValue.class), new Object[] { java.util.Objects.requireNonNull(key, "key is required"), options });
    }

    /**
     * Create a value from a key in the current process environment.
     * <p>
     * @param key - The key to read. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.EnvValue fromProcess(final @org.jetbrains.annotations.NotNull java.lang.String key) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.EnvValue.class, "fromProcess", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.EnvValue.class), new Object[] { java.util.Objects.requireNonNull(key, "key is required") });
    }

    /**
     * Defines an environment value from a secret JSON value.
     * <p>
     * @param secretValue The secret value (secrent + key). This parameter is required.
     * @param options Additional options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.EnvValue fromSecretValue(final @org.jetbrains.annotations.NotNull org.cdk8s.plus20.SecretValue secretValue, final @org.jetbrains.annotations.Nullable org.cdk8s.plus20.EnvValueFromSecretOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.EnvValue.class, "fromSecretValue", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.EnvValue.class), new Object[] { java.util.Objects.requireNonNull(secretValue, "secretValue is required"), options });
    }

    /**
     * Defines an environment value from a secret JSON value.
     * <p>
     * @param secretValue The secret value (secrent + key). This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.EnvValue fromSecretValue(final @org.jetbrains.annotations.NotNull org.cdk8s.plus20.SecretValue secretValue) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.EnvValue.class, "fromSecretValue", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.EnvValue.class), new Object[] { java.util.Objects.requireNonNull(secretValue, "secretValue is required") });
    }

    /**
     * Create a value from the given argument.
     * <p>
     * @param value - The value. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.EnvValue fromValue(final @org.jetbrains.annotations.NotNull java.lang.String value) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.EnvValue.class, "fromValue", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.EnvValue.class), new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.lang.Object getValue() {
        return software.amazon.jsii.Kernel.get(this, "value", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.lang.Object getValueFrom() {
        return software.amazon.jsii.Kernel.get(this, "valueFrom", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }
}

==> cdk8s-plus-20-2.0.0-beta.6-sources.jar: org/cdk8s/plus20/EnvValue.java <==
package org.cdk8s.plus20;

/**
 * Utility class for creating reading env values from various sources.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.59.0 (build eb02c92)", date = "2022-05-19T02:54:08.920Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = org.cdk8s.plus20.$Module.class, fqn = "cdk8s-plus-20.EnvValue")
public class EnvValue extends software.amazon.jsii.JsiiObject {

    protected EnvValue(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected EnvValue(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Create a value by reading a specific key inside a config map.
     * <p>
     * @param configMap - The config map. This parameter is required.
     * @param key - The key to extract the value from. This parameter is required.
     * @param options - Additional options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.EnvValue fromConfigMap(final @org.jetbrains.annotations.NotNull org.cdk8s.plus20.IConfigMap configMap, final @org.jetbrains.annotations.NotNull java.lang.String key, final @org.jetbrains.annotations.Nullable org.cdk8s.plus20.EnvValueFromConfigMapOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.EnvValue.class, "fromConfigMap", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.EnvValue.class), new Object[] { java.util.Objects.requireNonNull(configMap, "configMap is required"), java.util.Objects.requireNonNull(key, "key is required"), options });
    }

    /**
     * Create a value by reading a specific key inside a config map.
     * <p>
     * @param configMap - The config map. This parameter is required.
     * @param key - The key to extract the value from. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.EnvValue fromConfigMap(final @org.jetbrains.annotations.NotNull org.cdk8s.plus20.IConfigMap configMap, final @org.jetbrains.annotations.NotNull java.lang.String key) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.EnvValue.class, "fromConfigMap", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.EnvValue.class), new Object[] { java.util.Objects.requireNonNull(configMap, "configMap is required"), java.util.Objects.requireNonNull(key, "key is required") });
    }

    /**
     * Create a value from a field reference.
     * <p>
     * @param fieldPath : The field reference. This parameter is required.
     * @param options : Additional options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.EnvValue fromFieldRef(final @org.jetbrains.annotations.NotNull org.cdk8s.plus20.EnvFieldPaths fieldPath, final @org.jetbrains.annotations.Nullable org.cdk8s.plus20.EnvValueFromFieldRefOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.EnvValue.class, "fromFieldRef", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.EnvValue.class), new Object[] { java.util.Objects.requireNonNull(fieldPath, "fieldPath is required"), options });
    }

    /**
     * Create a value from a field reference.
     * <p>
     * @param fieldPath : The field reference. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.EnvValue fromFieldRef(final @org.jetbrains.annotations.NotNull org.cdk8s.plus20.EnvFieldPaths fieldPath) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.EnvValue.class, "fromFieldRef", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.EnvValue.class), new Object[] { java.util.Objects.requireNonNull(fieldPath, "fieldPath is required") });
    }

    /**
     * Create a value from a key in the current process environment.
     * <p>
     * @param key - The key to read. This parameter is required.
     * @param options - Additional options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.EnvValue fromProcess(final @org.jetbrains.annotations.NotNull java.lang.String key, final @org.jetbrains.annotations.Nullable org.cdk8s.plus20.EnvValueFromProcessOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.EnvValue.class, "fromProcess", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.EnvValue.class), new Object[] { java.util.Objects.requireNonNull(key, "key is required"), options });
    }

    /**
     * Create a value from a key in the current process environment.
     * <p>
     * @param key - The key to read. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.EnvValue fromProcess(final @org.jetbrains.annotations.NotNull java.lang.String key) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.EnvValue.class, "fromProcess", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.EnvValue.class), new Object[] { java.util.Objects.requireNonNull(key, "key is required") });
    }

    /**
     * Create a value from a resource.
     * <p>
     * @param resource : Resource to select the value from. This parameter is required.
     * @param options : Additional options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.EnvValue fromResource(final @org.jetbrains.annotations.NotNull org.cdk8s.plus20.ResourceFieldPaths resource, final @org.jetbrains.annotations.Nullable org.cdk8s.plus20.EnvValueFromResourceOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.EnvValue.class, "fromResource", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.EnvValue.class), new Object[] { java.util.Objects.requireNonNull(resource, "resource is required"), options });
    }

    /**
     * Create a value from a resource.
     * <p>
     * @param resource : Resource to select the value from. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.EnvValue fromResource(final @org.jetbrains.annotations.NotNull org.cdk8s.plus20.ResourceFieldPaths resource) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.EnvValue.class, "fromResource", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.EnvValue.class), new Object[] { java.util.Objects.requireNonNull(resource, "resource is required") });
    }

    /**
     * Defines an environment value from a secret JSON value.
     * <p>
     * @param secretValue The secret value (secrent + key). This parameter is required.
     * @param options Additional options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.EnvValue fromSecretValue(final @org.jetbrains.annotations.NotNull org.cdk8s.plus20.SecretValue secretValue, final @org.jetbrains.annotations.Nullable org.cdk8s.plus20.EnvValueFromSecretOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.EnvValue.class, "fromSecretValue", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.EnvValue.class), new Object[] { java.util.Objects.requireNonNull(secretValue, "secretValue is required"), options });
    }

    /**
     * Defines an environment value from a secret JSON value.
     * <p>
     * @param secretValue The secret value (secrent + key). This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.EnvValue fromSecretValue(final @org.jetbrains.annotations.NotNull org.cdk8s.plus20.SecretValue secretValue) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.EnvValue.class, "fromSecretValue", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.EnvValue.class), new Object[] { java.util.Objects.requireNonNull(secretValue, "secretValue is required") });
    }

    /**
     * Create a value from the given argument.
     * <p>
     * @param value - The value. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull org.cdk8s.plus20.EnvValue fromValue(final @org.jetbrains.annotations.NotNull java.lang.String value) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(org.cdk8s.plus20.EnvValue.class, "fromValue", software.amazon.jsii.NativeType.forClass(org.cdk8s.plus20.EnvValue.class), new Object[] { java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.lang.Object getValue() {
        return software.amazon.jsii.Kernel.get(this, "value", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.lang.Object getValueFrom() {
        return software.amazon.jsii.Kernel.get(this, "valueFrom", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
    }
}
